Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type AuthClient ¶
AuthClient handles webhook authentication
func NewAuthClient ¶
func NewAuthClient() (*AuthClient, error)
NewAuthClient creates a webhook authentication client using tokenfile defined environment 'config.Env.TokenFile' configuration. It uses `config.Env.OIDCAllowedGroups` envrionment configuration to allow access sepecific clients
func (*AuthClient) Authenticate ¶
func (a *AuthClient) Authenticate(token string) bool
Authenticate parse the jwt token provided as parameter to authenticate if the token is in jwt claims and request is comingß from authenticated groups the function will return true
type DeployRequest ¶
type DeployRequest struct {
Name string `json:"name"`
Application string `json:"application,omitempty"`
Version string
}
DeployRequest represents POST request body to perform deployments.
- Name of the service to update
- Application image part (full construct from util.DockerImage )
- Version application version
func ParseDeployRequest ¶
func ParseDeployRequest(body io.Reader) (*DeployRequest, error)
ParseDeployRequest returns DeployRequest struct based on HTTP request body
type StatusPods ¶
type StatusReplicas ¶
type StatusResponse ¶
type StatusResponse struct {
EnvironmentName string `json:"environment"`
Namespace string `json:"namespace"`
Services []StatusService `json:"services"`
}
type StatusService ¶
Click to show internal directories.
Click to hide internal directories.